==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/g_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_g.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_events'] = 							"events";
$lang['hdr_group_membership'] = 				"group membership";
$lang['hdr_library'] = 							"library";
$lang['hdr_recommended_s'] = 					"recommended discussions";
$lang['hdr_recommended_t'] = 					"recommended discussion topics";
$lang['hdr_statistics'] = 						"statistics";


//A HREF TAGS (links)
$lang['href_join'] = 							"join";


//BODY TEXT
$lang['txt_group_apply'] = 						"want to join this group?";
$lang['txt_group_genre'] = 						"group genre";
$lang['txt_group_language'] = 					"language";
$lang['txt_group_type'] = 						"group type";
$lang['txt_membership_status'] = 				"membership status";
$lang['txt_rec_age'] = 							"recommended age";

?>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/g_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_activities'] = 						"activities";
$lang['hdr_library'] = 							"library";
$lang['hdr_recommended_s'] = 					"recommended discussions";
$lang['hdr_recommended_b'] = 					"recommended blogs";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_tasks'] = 							"tasks";


//A HREF TAGS (links)
$lang['href_join'] = 							"join";


//BODY TEXT
$lang['txt_group_apply'] = 						"want to join this group?";
$lang['txt_group_genre'] = 						"group genre";
$lang['txt_group_language'] = 					"language";
$lang['txt_group_type'] = 						"group type";
$lang['txt_membership_status'] = 				"membership status";
$lang['txt_rec_age'] = 							"recommended age";

?>
